<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Blog Page Pro
 * @since Blog Page Pro 1.0.0
 */

if ( ! function_exists( 'blog_page_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Blog Page Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_page_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'blog_page_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'blog_page_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Blog Page Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_page_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'blog_page_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'blog_page_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Blog Page Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_page_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'blog_page_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if banner section is enabled.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_banner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_page_pro_theme_options[banner_section_enable]' )->value() );
}

/**
 * Check if banner section content type is post.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_banner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[banner_content_type]' )->value();
	return blog_page_pro_is_banner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if banner section content type is page.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_banner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[banner_content_type]' )->value();
	return blog_page_pro_is_banner_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section is enabled.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_page_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is post.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[featured_content_type]' )->value();
	return blog_page_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section content type is page.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[featured_content_type]' )->value();
	return blog_page_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is category.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[featured_content_type]' )->value();
	return blog_page_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent_articles section is enabled.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_recent_articles_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_page_pro_theme_options[recent_articles_section_enable]' )->value() );
}

/**
 * Check if recent_articles section content type is post.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_recent_articles_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[recent_articles_content_type]' )->value();
	return blog_page_pro_is_recent_articles_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_articles section content type is page.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_recent_articles_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[recent_articles_content_type]' )->value();
	return blog_page_pro_is_recent_articles_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_articles section content type is category.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_recent_articles_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[recent_articles_content_type]' )->value();
	return blog_page_pro_is_recent_articles_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_articles section is enabled.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_popular_articles_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_page_pro_theme_options[popular_articles_section_enable]' )->value() );
}

/**
 * Check if popular_articles section content type is post.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_popular_articles_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[popular_articles_content_type]' )->value();
	return blog_page_pro_is_popular_articles_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_articles section content type is page.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_popular_articles_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[popular_articles_content_type]' )->value();
	return blog_page_pro_is_popular_articles_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_articles section content type is category.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_popular_articles_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[popular_articles_content_type]' )->value();
	return blog_page_pro_is_popular_articles_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if list_articles section is enabled.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_list_articles_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_page_pro_theme_options[list_articles_section_enable]' )->value() );
}

/**
 * Check if list_articles section content type is post.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_list_articles_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[list_articles_content_type]' )->value();
	return blog_page_pro_is_list_articles_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if list_articles section content type is page.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_list_articles_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[list_articles_content_type]' )->value();
	return blog_page_pro_is_list_articles_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if list_articles section content type is category.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_list_articles_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[list_articles_content_type]' )->value();
	return blog_page_pro_is_list_articles_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_page_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[blog_content_type]' )->value();
	return blog_page_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[blog_content_type]' )->value();
	return blog_page_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[blog_content_type]' )->value();
	return blog_page_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Blog Page Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_page_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_page_pro_theme_options[blog_content_type]' )->value();
	return blog_page_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
