<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Blog Page Pro
 * @since Blog Page Pro 1.0.0
 * @return array An array of default values
 */

function blog_page_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$blog_page_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#ff696a',
		'header_tagline_color'			=> '#322d2d',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,
		'subscription_enable'			=> false,

		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'blog-page-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'blog-page-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'blog-page-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Banner,Featured,Recent Articles,Popular Articles,List Articles,Blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'blog-page-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,
		'archive_column'				=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Banner
		'banner_section_enable'			=> true,
		'banner_content_type'			=> 'page',

		// featured
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'category',
		'featured_count'				=> 3,
		'featured_column'				=> 'col-3',

		// recent_articles
		'recent_articles_section_enable' => true,
		'recent_articles_content_type'	=> 'category',
		'recent_articles_count'			=> 6,
		'recent_articles_column'		=> 'col-3',
		'recent_articles_title'			=> esc_html__( 'Recent Articles', 'blog-page-pro' ),
		'recent_articles_subtitle'		=> esc_html__( 'Most recent posts from Blog Page to readers', 'blog-page-pro' ), 
		'recent_articles_btn_title'		=> esc_html__( 'View All', 'blog-page-pro' ), 

		// popular_articles
		'popular_articles_section_enable' => true,
		'popular_articles_content_type'	=> 'category',
		'popular_articles_count'		=> 7,
		'popular_articles_title'		=> esc_html__( 'Popular Articles', 'blog-page-pro' ),
		'popular_articles_subtitle'		=> esc_html__( 'Most popular posts from Blog Page to readers', 'blog-page-pro' ), 
		'popular_articles_btn_title'	=> esc_html__( 'View All Articles', 'blog-page-pro' ), 


		// list_articles
		'list_articles_section_enable' 	=> true,
		'list_articles_content_type'	=> 'category',
		'list_articles_count'			=> 4,
		'list_articles_title'			=> esc_html__( 'Photography Articles', 'blog-page-pro' ),
		'list_articles_subtitle'		=> esc_html__( 'Photography related post is here to amaze you', 'blog-page-pro' ), 
		'list_articles_btn_title'		=> esc_html__( 'View All Articles', 'blog-page-pro' ), 
		'list_articles_readmore'		=> esc_html__( 'Continue Reading', 'blog-page-pro' ), 

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'Lifestyle And Fashion', 'blog-page-pro' ),
		'blog_subtitle'					=> esc_html__( 'Everything you need to know about fashionable lifestyle', 'blog-page-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Articles', 'blog-page-pro' ),

	);

	$output = apply_filters( 'blog_page_pro_default_theme_options', $blog_page_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}