<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Blog Page Pro
 * @since Blog Page Pro 1.0.0
 */

$options = blog_page_pro_get_theme_options();


if ( ! function_exists( 'blog_page_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Blog Page Pro 1.0.0
	 */
	function blog_page_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'blog_page_pro_doctype', 'blog_page_pro_doctype', 10 );


if ( ! function_exists( 'blog_page_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'blog_page_pro_before_wp_head', 'blog_page_pro_head', 10 );

if ( ! function_exists( 'blog_page_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'blog-page-pro' ); ?></a>

		<?php
	}
endif;
add_action( 'blog_page_pro_page_start_action', 'blog_page_pro_page_start', 10 );

if ( ! function_exists( 'blog_page_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'blog_page_pro_page_end_action', 'blog_page_pro_page_end', 10 );

if ( ! function_exists( 'blog_page_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_header_start() { ?>
        <div class="menu-overlay"></div>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
			 	<div id="site-menu">
		<?php
	}
endif;
add_action( 'blog_page_pro_header_action', 'blog_page_pro_header_start', 10 );

if ( ! function_exists( 'blog_page_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_site_branding() {
		$options  = blog_page_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">
			<div class="site-branding-wrapper">
				<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
					<div class="site-logo">
						<?php the_custom_logo(); ?>
					</div>
				<?php } 
				if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
					<div id="site-details">
						<?php
						if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
							if ( blog_page_pro_is_latest_posts() ) : ?>
								<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php else : ?>
								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
							endif;
						} 
						if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
							$description = get_bloginfo( 'description', 'display' );
							if ( $description || is_customize_preview() ) : ?>
								<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
							<?php
							endif; 
						}?>
					</div>
				<?php endif; ?>
			</div><!-- .site-branding-wrapper -->
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'blog_page_pro_header_action', 'blog_page_pro_site_branding', 20 );

if ( ! function_exists( 'blog_page_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_site_navigation() { 
		$options = blog_page_pro_get_theme_options();
		?>
		<button class="menu-toggle" aria-controls="secondary-menu" aria-expanded="false">
			<span class="menu-label"><?php esc_html_e( 'Menu', 'blog-page-pro' ); ?></span>
			<?php
			echo blog_page_pro_get_svg( array( 'icon' => 'down', 'class' => 'icon-menu' ) );
			?>					
		</button>
		<nav id="secondary-navigation" class="secondary-navigation main-navigate" role="navigation">
			<?php  
				$subscription_shortcode = '';
				if ( $options['subscription_enable'] ) :
					if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) ) :
						$subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_attr__( 'Subscribe', 'blog-page-pro' ) . '" show_subscribers_total=""]';
                        $subscription_shortcode = do_shortcode( wp_kses_post( $subscription_shortcode ) );
	                endif;
                endif;

                wp_nav_menu(
                	array(
                		'theme_location' => 'secondary',
                		'container' => false,
                		'menu_class' => 'menu nav-menu',
                		'menu_id' => 'secondary-menu',
                		'echo' => true,
                		'fallback_cb' => 'blog_page_pro_menu_fallback_cb',
                		'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s <li>' . $subscription_shortcode . '</li></ul>',
                		)
                	);
        	?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'blog_page_pro_header_action', 'blog_page_pro_site_navigation', 30 );



if ( ! function_exists( 'blog_page_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_header_end() {
		?>
			</div><!-- .site-menu -->
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'blog_page_pro_header_action', 'blog_page_pro_header_end', 40 );

if ( ! function_exists( 'blog_page_pro_primary_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_primary_site_navigation() {
		$options = blog_page_pro_get_theme_options();
		?>
		 <div id="navigation-menu" class="relative">
            <div class="wrapper">
                <button class="primary-menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                    <?php
						echo blog_page_pro_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu-bar' ) );
						echo blog_page_pro_get_svg( array( 'icon' => 'close' ) );
					?>
                </button><!-- .menu-toggle -->

                <nav id="site-navigation" class="main-navigation main-navigate" role="navigation">
					<?php  
						$search = '';
						if ( $options['nav_search_enable'] ) :
							$search = '<li class="search-menu"><a href="#">';
							$search .= blog_page_pro_get_svg( array( 'icon' => 'search' ) );
							$search .= blog_page_pro_get_svg( array( 'icon' => 'close' ) );
							$search .= '</a><div id="search">';
							$search .= get_search_form( $echo = false );
			                $search .= '</div><!-- #search --></li>';
		                endif;

		                wp_nav_menu(
		                	array(
		                		'theme_location' => 'primary',
		                		'container' => false,
		                		'menu_class' => 'menu nav-menu',
		                		'menu_id' => 'primary-menu',
		                		'echo' => true,
		                		'fallback_cb' => 'blog_page_pro_menu_fallback_cb',
		                		'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
		                		)
		                	);
		  		        	?>
	    		</div><!-- #site-navigation -->
			</div><!-- #navigation-menu -->
		<?php
	}
endif;
add_action( 'blog_page_pro_header_action', 'blog_page_pro_primary_site_navigation', 50 );

if ( ! function_exists( 'blog_page_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'blog_page_pro_content_start_action', 'blog_page_pro_content_start', 10 );

if ( ! function_exists( 'blog_page_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_header_image() {
		if ( blog_page_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		if ( is_singular() ) :
			$header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
		endif;
		?>

		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <h2 class="page-title"><?php blog_page_pro_custom_header_banner_title(); ?></h2>
                </header>

                <?php blog_page_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->

	<?php
	}
endif;
add_action( 'blog_page_pro_header_image_action', 'blog_page_pro_header_image', 10 );

if ( ! function_exists( 'blog_page_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Blog Page Pro 1.0.0
	 */
	function blog_page_pro_add_breadcrumb() {
		$options = blog_page_pro_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( blog_page_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * blog_page_pro_simple_breadcrumb hook
				 *
				 * @hooked blog_page_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'blog_page_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'blog_page_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'blog_page_pro_content_end_action', 'blog_page_pro_content_end', 10 );

if ( ! function_exists( 'blog_page_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'blog_page_pro_footer', 'blog_page_pro_footer_start', 10 );

if ( ! function_exists( 'blog_page_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_footer_site_info() {
		$options = blog_page_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );
        $options['powered_by_text'] = str_replace( $search, $replace, $options['powered_by_text'] );

		$copyright_text = $options['copyright_text']; 
		$powered_by_text = $options['powered_by_text'];
		?>
		<div class="site-info col-2">
                <div class="wrapper">
                    <span>
                    	<?php 
                    	echo blog_page_pro_santize_allow_tag( $copyright_text ); 
                    	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
                    	?>
                	</span>
                    <span><?php echo blog_page_pro_santize_allow_tag( $powered_by_text ); ?></span>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'blog_page_pro_footer', 'blog_page_pro_footer_site_info', 40 );

if ( ! function_exists( 'blog_page_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_footer_scroll_to_top() {
		$options  = blog_page_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo blog_page_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'blog_page_pro_footer', 'blog_page_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'blog_page_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'blog_page_pro_footer', 'blog_page_pro_footer_end', 100 );

if ( ! function_exists( 'blog_page_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_loader() {
		$options = blog_page_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
	            <div class="loader-container">
	            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
		                <div id="preloader">
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                </div>
		            <?php else :
		            	echo blog_page_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
		            endif; ?>
	            </div>
	        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'blog_page_pro_before_header', 'blog_page_pro_loader', 10 );

if ( ! function_exists( 'blog_page_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Blog Page Pro 1.0.0
	 *
	 */
	function blog_page_pro_infinite_loader_spinner() { 
		global $post;
		$options = blog_page_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( $post ) > 0 ) {
				echo '<div class="blog-loader">' . blog_page_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'blog_page_pro_infinite_loader_spinner_action', 'blog_page_pro_infinite_loader_spinner', 10 );
